import sys
import typing


def EventToCharacter(event: int, shift: bool):
    ''' Return the string name of a key event. Returns an empty string if the event cant be represented as a character.

    :param event: bge.events or the keyboard sensor.
    :type event: int
    :param shift: set to true if shift is held.
    :type shift: bool
    '''

    pass


def EventToString(event: int):
    ''' Return the string name of a key event. Will raise a ValueError error if its invalid.

    :param event: bge.events or the keyboard sensor.
    :type event: int
    '''

    pass


ACCENTGRAVEKEY = None

AKEY = None

BACKSLASHKEY = None

BACKSPACEKEY = None

BKEY = None

BUTTON4MOUSE = None

BUTTON5MOUSE = None

BUTTON6MOUSE = None

BUTTON7MOUSE = None

CAPSLOCKKEY = None

CKEY = None

COMMAKEY = None

DELKEY = None

DKEY = None

DOWNARROWKEY = None

EIGHTKEY = None

EKEY = None

ENDKEY = None

ENTERKEY = None

EQUALKEY = None

ESCKEY = None

F10KEY = None

F11KEY = None

F12KEY = None

F13KEY = None

F14KEY = None

F15KEY = None

F16KEY = None

F17KEY = None

F18KEY = None

F19KEY = None

F1KEY = None

F2KEY = None

F3KEY = None

F4KEY = None

F5KEY = None

F6KEY = None

F7KEY = None

F8KEY = None

F9KEY = None

FIVEKEY = None

FKEY = None

FOURKEY = None

GKEY = None

HKEY = None

HOMEKEY = None

IKEY = None

INSERTKEY = None

JKEY = None

KKEY = None

LEFTALTKEY = None

LEFTARROWKEY = None

LEFTBRACKETKEY = None

LEFTCTRLKEY = None

LEFTMOUSE = None

LEFTSHIFTKEY = None

LINEFEEDKEY = None

LKEY = None

MIDDLEMOUSE = None

MINUSKEY = None

MKEY = None

MOUSEX = None

MOUSEY = None

NINEKEY = None

NKEY = None

OKEY = None

ONEKEY = None

PAD0 = None

PAD1 = None

PAD2 = None

PAD3 = None

PAD4 = None

PAD5 = None

PAD6 = None

PAD7 = None

PAD8 = None

PAD9 = None

PADASTERKEY = None

PADENTER = None

PADMINUS = None

PADPERIOD = None

PADPLUSKEY = None

PADSLASHKEY = None

PAGEDOWNKEY = None

PAGEUPKEY = None

PAUSEKEY = None

PERIODKEY = None

PKEY = None

QKEY = None

QUOTEKEY = None

RETKEY = None

RIGHTALTKEY = None

RIGHTARROWKEY = None

RIGHTBRACKETKEY = None

RIGHTCTRLKEY = None

RIGHTMOUSE = None

RIGHTSHIFTKEY = None

RKEY = None

SEMICOLONKEY = None

SEVENKEY = None

SIXKEY = None

SKEY = None

SLASHKEY = None

SPACEKEY = None

TABKEY = None

THREEKEY = None

TKEY = None

TWOKEY = None

UKEY = None

UPARROWKEY = None

VKEY = None

WHEELDOWNMOUSE = None

WHEELUPMOUSE = None

WKEY = None

XKEY = None

YKEY = None

ZEROKEY = None

ZKEY = None
