import sys
import typing


def add_row_filter_rule():
    ''' Add a filter to remove rows from the displayed data

    '''

    pass


def change_spreadsheet_data_source(component_type: int = 0,
                                   attribute_domain_type: int = 0):
    ''' Change visible data source in the spreadsheet

    :param component_type: Component Type
    :type component_type: int
    :param attribute_domain_type: Attribute Domain Type
    :type attribute_domain_type: int
    '''

    pass


def remove_row_filter_rule(index: int = 0):
    ''' Remove a row filter from the rules

    :param index: Index
    :type index: int
    '''

    pass


def toggle_pin():
    ''' Turn on or off pinning :file: startup/bl_operators/spreadsheet.py\:19 <https://projects.blender.org/blender/blender/src/branch/main/release/scripts/startup/bl_operators/spreadsheet.py$19> _

    '''

    pass
