import sys
import typing


class ConsoleLogger:
    name = None
    ''' '''

    def acquire(self):
        ''' 

        '''
        pass

    def addFilter(self, filter):
        ''' 

        '''
        pass

    def close(self):
        ''' 

        '''
        pass

    def createLock(self):
        ''' 

        '''
        pass

    def emit(self, record):
        ''' 

        '''
        pass

    def filter(self, record):
        ''' 

        '''
        pass

    def flush(self):
        ''' 

        '''
        pass

    def format(self, record):
        ''' 

        '''
        pass

    def get_name(self):
        ''' 

        '''
        pass

    def handle(self, record):
        ''' 

        '''
        pass

    def handleError(self, record):
        ''' 

        '''
        pass

    def release(self):
        ''' 

        '''
        pass

    def removeFilter(self, filter):
        ''' 

        '''
        pass

    def setFormatter(self, fmt):
        ''' 

        '''
        pass

    def setLevel(self, level):
        ''' 

        '''
        pass

    def set_name(self, name):
        ''' 

        '''
        pass


def setup(log_level):
    ''' 

    '''

    pass
