import sys
import typing


def add_node_type(layout, node_type, label):
    ''' 

    '''

    pass


def draw_assets_for_catalog(layout, catalog_path):
    ''' 

    '''

    pass


def draw_node_group_add_menu(context, layout):
    ''' 

    '''

    pass


def draw_root_assets(layout):
    ''' 

    '''

    pass
