import sys
import typing


def execute_preset(filepath: str = "", menu_idname: str = ""):
    ''' Load a preset

    :param filepath: filepath
    :type filepath: str
    :param menu_idname: Menu ID Name, ID name of the menu this was called from
    :type menu_idname: str
    '''

    pass


def python_file_run(filepath: str = ""):
    ''' Run Python file

    :param filepath: Path
    :type filepath: str
    '''

    pass


def reload():
    ''' Reload scripts

    '''

    pass
